Requirements and Installation
=============================

Requirements
------------

Runtime
^^^^^^^

* Django 1.4+
* South 0.7.6+
* django-templatetag-handlebars 1.2.0+

Development
^^^^^^^^^^^

In addition to Runtime requirements above:

* django-discover-runner (for running the unit tests)
* sqlite3 (default) or any other RDBMS supported by Django
* Sphinx (only to generate docs)

Installation
------------

You can pip install using a link from the downloads page:

https://github.com/sztamas/django-iprestrict/downloads

Example for version 0.1::

  $ pip install https://github.com/sztamas/django-iprestrict/downloads/django-iprestrict_0.1.tar.gz 

or download the latest version from the downloads page and easy_install it:

Example for version 0.1::

$ easy_install django_iprestrict_0.1.tar.gz


